==> countries_dictionary-3.0.1-py3-none-any.whl: countries_dictionary/vietnam.py <==
VIETNAM = {
    "Hanoi": {
        "region": "Red River Delta",
        "administrative centre": "Hoàn Kiếm ward",
        "area": 3359.84,
        "population": 8807523},
    "Ho Chi Minh City": {
        "region": "Southeast",
        "administrative centre": "Saigon ward",
        "area": 6772.59,
        "population": 14002598},
    "Haiphong": {
        "region": "Red River Delta",
        "administrative centre": "Hồng Bàng ward",
        "area": 3194.72,
        "population": 4664124},
    "Da Nang": {    # Includes Hoàng Sa
        "region": "South Central Coast",
        "administrative centre": "Hải Châu ward",
        "area": 11859.59,
        "population": 3065628},
    "Cần Thơ": {
        "region": "Mekong Delta",
        "administrative centre": "Ninh Kiều ward",
        "area": 6360.83,
        "population": 4199824},
    "Huế": {
        "region": "North Central Coast",
        "administrative centre": "Thuận Hóa ward",
        "area": 4947.11,
        "population": 1432986},
    "Điện Biên province": {
        "region": "Northwest",
        "administrative centre": "Điện Biên Phủ ward",
        "area": 9539.93,
        "population": 673091},
    "Lai Châu province": {
        "region": "Northwest",
        "administrative centre": "Tân Phong ward",
        "area": 9068.73,
        "population": 512601},
    "Lào Cai province": {
        "region": "Northwest",
        "administrative centre": "Yên Bái ward",
        "area": 13256.92,
        "population": 1778785},
    "Cao Bằng province": {
        "region": "Northeast",
        "administrative centre": "Thục Phán ward",
        "area": 6700.39,
        "population": 573119},
    "Lạng Sơn province": {
        "region": "Northeast",
        "administrative centre": "Lương Văn Tri ward",
        "area": 8310.18,
        "population": 881384},
    "Tuyên Quang province": {
        "region": "Northeast",
        "administrative centre": "Minh Xuân ward",
        "area": 13795.5,
        "population": 1865270},
    "Thái Nguyên province": {
        "region": "Northeast",
        "administrative centre": "Phan Đình Phùng ward",
        "area": 8375.21,
        "population": 1799489},
    "Sơn La province": {
        "region": "Northwest",
        "administrative centre": "Chiềng Cơi ward",
        "area": 14108.89,
        "population": 1404587},
    "Phú Thọ province": {
        "region": "Northeast",
        "administrative centre": "Việt Trì ward",
        "area": 9361.38,
        "population": 4022638},
    "Bắc Ninh province": {
        "region": "Red River Delta",
        "administrative centre": "Tân Tiến ward",
        "area": 3194.72,
        "population": 3619433},
    "Quảng Ninh province": {
        "region": "Northeast",
        "administrative centre": "Hạ Long ward",
        "area": 6207.95,
        "population": 1497477},
    "Hưng Yên province": {
        "region": "Red River Delta",
        "administrative centre": "Phố Hiến ward",
        "area": 2514.81,
        "population": 3567943},
    "Ninh Bình province": {
        "region": "Red River Delta",
        "administrative centre": "Hoa Lư ward",
        "area": 3942.62,
        "population": 4412464},
    "Thanh Hóa province": {
        "region": "North Central Coast",
        "administrative centre": "Hạc Thành ward",
        "area": 11114.71,
        "population": 4324783},
    "Nghệ An province": {
        "region": "North Central Coast",
        "administrative centre": "Trường Vinh ward",
        "area": 16486.5,
        "population": 3831694},
    "Hà Tĩnh province": {
        "region": "North Central Coast",
        "administrative centre": "Thành Sen ward",
        "area": 5994.45,
        "population": 1622901},
    "Quảng Trị province": {
        "region": "North Central Coast",
        "administrative centre": "Đồng Hới ward",
        "area": 12700.0,
        "population": 1870845},
    "Quảng Ngãi province": {
        "region": "South Central Coast",
        "administrative centre": "Cẩm Thành ward",
        "area": 14832.55,
        "population": 2161755},
    "Gia Lai province": {
        "region": "South Central Coast",
        "administrative centre": "Quy Nhơn ward",
        "area": 21576.93,
        "population": 3583693},
    "Đắk Lắk province": {
        "region": "South Central Coast",
        "administrative centre": "Buôn Ma Thuột ward",
        "area": 18096.4,
        "population": 3346853},
    "Khánh Hòa province": {    # Includes Trường Sa
        "region": "South Central Coast",
        "administrative centre": "Nha Trang ward",
        "area": 8555.86,
        "population": 2243554},
    "Lâm Đồng province": {
        "region": "South Central Coast",
        "administrative centre": "Xuân Hương – Đà Lạt ward",
        "area": 24233.07,
        "population": 3872999},
    "Tây Ninh province": {
        "region": "Southeast",
        "administrative centre": "Long An ward",
        "area": 8536.44,
        "population": 3254170},
    "Đồng Nai province": {
        "region": "Southeast",
        "administrative centre": "Trấn Biên ward",
        "area": 12737.18,
        "population": 4491408},
    "Đồng Tháp province": {
        "region": "Mekong Delta",
        "administrative centre": "Mỹ Tho ward",
        "area": 5938.64,
        "population": 4370046},
    "An Giang province": {
        "region": "Mekong Delta",
        "administrative centre": "Rạch Giá ward",
        "area": 9888.91,
        "population": 4952238},
    "Vĩnh Long province": {
        "region": "Mekong Delta",
        "administrative centre": "Long Châu ward",
        "area": 6296.2,
        "population": 4257581},
    "Cà Mau province": {
        "region": "Mekong Delta",
        "administrative centre": "Tân Thành ward",
        "area": 7942.39,
        "population": 2606672},
    # Source: https://en.wikipedia.org/wiki/Provinces_of_Vietnam
}
"""A dictionary contains all provinces and municipalities of Vietnam and information about them:
- Region
- Administrative centre
- Area (in square kilometre)
- Population

Note: the dictionary might contain inaccuracies"""

==> countries_dictionary-3.1.4-py3-none-any.whl: countries_dictionary/vietnam.py <==
VIETNAM = {
    "Hanoi": {
        "region": "Red River Delta",
        "administrative centre": "Hoàn Kiếm ward",
        "area": 3359.84,
        "population": 8807523,
    },
    "Ho Chi Minh City": {
        "region": "Southeast",
        "administrative centre": "Saigon ward",
        "area": 6772.59,
        "population": 14002598,
    },
    "Haiphong": {
        "region": "Red River Delta",
        "administrative centre": "Hồng Bàng ward",
        "area": 3194.72,
        "population": 4664124,
    },
    "Da Nang": {    # Includes Hoàng Sa
        "region": "South Central Coast",
        "administrative centre": "Hải Châu ward",
        "area": 11859.59,
        "population": 3065628,
    },
    "Cần Thơ": {
        "region": "Mekong Delta",
        "administrative centre": "Ninh Kiều ward",
        "area": 6360.83,
        "population": 4199824,
    },
    "Huế": {
        "region": "North Central Coast",
        "administrative centre": "Thuận Hóa ward",
        "area": 4947.11,
        "population": 1432986,
    },
    "Điện Biên province": {
        "region": "Northwest",
        "administrative centre": "Điện Biên Phủ ward",
        "area": 9539.93,
        "population": 673091,
    },
    "Lai Châu province": {
        "region": "Northwest",
        "administrative centre": "Tân Phong ward",
        "area": 9068.73,
        "population": 512601,
    },
    "Lào Cai province": {
        "region": "Northwest",
        "administrative centre": "Yên Bái ward",
        "area": 13256.92,
        "population": 1778785,
    },
    "Cao Bằng province": {
        "region": "Northeast",
        "administrative centre": "Thục Phán ward",
        "area": 6700.39,
        "population": 573119,
    },
    "Lạng Sơn province": {
        "region": "Northeast",
        "administrative centre": "Lương Văn Tri ward",
        "area": 8310.18,
        "population": 881384,
    },
    "Tuyên Quang province": {
        "region": "Northeast",
        "administrative centre": "Minh Xuân ward",
        "area": 13795.5,
        "population": 1865270,
    },
    "Thái Nguyên province": {
        "region": "Northeast",
        "administrative centre": "Phan Đình Phùng ward",
        "area": 8375.21,
        "population": 1799489,
    },
    "Sơn La province": {
        "region": "Northwest",
        "administrative centre": "Chiềng Cơi ward",
        "area": 14108.89,
        "population": 1404587,
    },
    "Phú Thọ province": {
        "region": "Northeast",
        "administrative centre": "Việt Trì ward",
        "area": 9361.38,
        "population": 4022638,
    },
    "Bắc Ninh province": {
        "region": "Red River Delta",
        "administrative centre": "Tân Tiến ward",
        "area": 3194.72,
        "population": 3619433,
    },
    "Quảng Ninh province": {
        "region": "Northeast",
        "administrative centre": "Hạ Long ward",
        "area": 6207.95,
        "population": 1497477,
    },
    "Hưng Yên province": {
        "region": "Red River Delta",
        "administrative centre": "Phố Hiến ward",
        "area": 2514.81,
        "population": 3567943,
    },
    "Ninh Bình province": {
        "region": "Red River Delta",
        "administrative centre": "Hoa Lư ward",
        "area": 3942.62,
        "population": 4412464,
    },
    "Thanh Hóa province": {
        "region": "North Central Coast",
        "administrative centre": "Hạc Thành ward",
        "area": 11114.71,
        "population": 4324783,
    },
    "Nghệ An province": {
        "region": "North Central Coast",
        "administrative centre": "Trường Vinh ward",
        "area": 16486.5,
        "population": 3831694,
    },
    "Hà Tĩnh province": {
        "region": "North Central Coast",
        "administrative centre": "Thành Sen ward",
        "area": 5994.45,
        "population": 1622901,
    },
    "Quảng Trị province": {
        "region": "North Central Coast",
        "administrative centre": "Đồng Hới ward",
        "area": 12700.0,
        "population": 1870845,
    },
    "Quảng Ngãi province": {
        "region": "South Central Coast",
        "administrative centre": "Cẩm Thành ward",
        "area": 14832.55,
        "population": 2161755,
    },
    "Gia Lai province": {
        "region": "South Central Coast",
        "administrative centre": "Quy Nhơn ward",
        "area": 21576.93,
        "population": 3583693,
    },
    "Đắk Lắk province": {
        "region": "South Central Coast",
        "administrative centre": "Buôn Ma Thuột ward",
        "area": 18096.4,
        "population": 3346853,
    },
    "Khánh Hòa province": {    # Includes Trường Sa
        "region": "South Central Coast",
        "administrative centre": "Nha Trang ward",
        "area": 8555.86,
        "population": 2243554,
    },
    "Lâm Đồng province": {
        "region": "South Central Coast",
        "administrative centre": "Xuân Hương – Đà Lạt ward",
        "area": 24233.07,
        "population": 3872999,
    },
    "Tây Ninh province": {
        "region": "Southeast",
        "administrative centre": "Long An ward",
        "area": 8536.44,
        "population": 3254170,
    },
    "Đồng Nai province": {
        "region": "Southeast",
        "administrative centre": "Trấn Biên ward",
        "area": 12737.18,
        "population": 4491408,
    },
    "Đồng Tháp province": {
        "region": "Mekong Delta",
        "administrative centre": "Mỹ Tho ward",
        "area": 5938.64,
        "population": 4370046,
    },
    "An Giang province": {
        "region": "Mekong Delta",
        "administrative centre": "Rạch Giá ward",
        "area": 9888.91,
        "population": 4952238,
    },
    "Vĩnh Long province": {
        "region": "Mekong Delta",
        "administrative centre": "Long Châu ward",
        "area": 6296.2,
        "population": 4257581,
    },
    "Cà Mau province": {
        "region": "Mekong Delta",
        "administrative centre": "Tân Thành ward",
        "area": 7942.39,
        "population": 2606672,
    },
    # Source: https://en.wikipedia.org/wiki/Provinces_of_Vietnam
}
"""A dictionary contains all provinces and municipalities of Vietnam and information about them:
- Region
- Administrative centre
- Area (in square kilometre)
- Population

Note: the dictionary might contain inaccuracies"""
